@@ -42,54 +42,62 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
         // line 1
         yield "<!DOCTYPE html>
 <html>
-    ";
+";
         // line 3
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
-array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
-        // line 7
+        $context["brand"] = "Cause Buzz";
+        // line 4
+        yield "
+";
+        // line 5
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => (((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks) && !CoreExtension::inFilter(        $this->unwrap()->renderBlock("headerTitle", $context, $blocks), ["", "Mautic"]))) ? (((        $this->unwrap()->renderBlock("headerTitle", $context, $blocks) . " | ") .         // line 7
+(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 7, $this->source); })()))) : (        // line 8
+(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 8, $this->source); })()))), "pageTitle" => (((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks) && !CoreExtension::inFilter(        $this->unwrap()->renderBlock("pageTitle", $context, $blocks), ["", "Mautic"]))) ? (((        $this->unwrap()->renderBlock("pageTitle", $context, $blocks) . " | ") .         // line 10
+(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 10, $this->source); })()))) : (        // line 11
+(isset($context["brand"]) || array_key_exists("brand", $context) ? $context["brand"] : (function () { throw new RuntimeError('Variable "brand" does not exist.', 11, $this->source); })())))]);
+        // line 12
         yield "
     <body class=\"header-fixed\">
         <section id=\"app-wrapper\">
             ";
-        // line 10
+        // line 15
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyOpen");
         yield "
 
             ";
-        // line 12
+        // line 17
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Notification/flashes.html.twig");
         yield "
             ";
-        // line 13
+        // line 18
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Menu/quick_help.html.twig");
         yield "
             ";
-        // line 14
+        // line 19
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/tokens_help.html.twig");
         yield "
             ";
-        // line 15
+        // line 20
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/keyboard_shortcuts.html.twig");
         yield "
             ";
-        // line 16
+        // line 21
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Modal/search_commands.html.twig");
         yield "
             ";
-        // line 17
+        // line 22
         yield $this->env->getRuntime('Symfony\Bridge\Twig\Extension\HttpKernelRuntime')->renderFragment(Symfony\Bridge\Twig\Extension\HttpKernelExtension::controller("Mautic\\CoreBundle\\Controller\\DefaultController::globalSearchAction"));
         yield "
 
             <aside class=\"app-sidebar sidebar-left\">
                 ";
-        // line 20
+        // line 25
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/LeftPanel/index.html.twig");
         yield "
             </aside>
 
             <header id=\"app-header\" class=\"navbar\">
                 ";
-        // line 24
+        // line 29
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/navbar.html.twig");
         yield "
             </header>
@@ -99,11 +107,11 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
                 <div class=\"container-fluid\">
                     <div class=\"row\">
                         <div class=\"col-xs-6 text-muted\">© ";
-        // line 31
+        // line 36
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Twig\Extension\CoreExtension']->formatDate("now", "Y"), "html", null, true);
         yield " Cause Buzz. Alle Rechte vorbehalten.</div>
                         <div class=\"col-xs-6 text-muted text-right small\">v";
-        // line 32
+        // line 37
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Mautic\CoreBundle\Twig\Extension\VersionExtension']->getVersion(), "html", null, true);
         yield "</div>
                     </div>
@@ -113,17 +121,17 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
 
             <section id=\"app-content\">
                 ";
-        // line 39
+        // line 44
         yield from $this->unwrap()->yieldBlock('_content', $context, $blocks);
-        // line 42
+        // line 47
         yield "            </section>
 
             <script>
                 Mautic.onPageLoad('body');
                 ";
-        // line 46
-        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 46, $this->source); })()), "environment", [], "any", false, false, false, 46) === "dev")) {
-            // line 47
+        // line 51
+        if ((CoreExtension::getAttribute($this->env, $this->source, (isset($context["app"]) || array_key_exists("app", $context) ? $context["app"] : (function () { throw new RuntimeError('Variable "app" does not exist.', 51, $this->source); })()), "environment", [], "any", false, false, false, 51) === "dev")) {
+            // line 52
             yield "                mQuery( document ).ajaxComplete(function(event, XMLHttpRequest, ajaxOption){
                     if(XMLHttpRequest.responseJSON && typeof XMLHttpRequest.responseJSON.ignore_wdt == 'undefined' && XMLHttpRequest.getResponseHeader('x-debug-token')) {
                         if (mQuery('[class*=\"sf-tool\"]').length) {
@@ -137,17 +145,17 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
                 });
                 ";
         }
-        // line 59
+        // line 64
         yield "            </script>
 
             ";
-        // line 61
+        // line 66
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 62
+        // line 67
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 65
+        // line 70
         yield "
         </section>
     </body>
@@ -157,14 +165,14 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         yield from [];
     }
 
-    // line 39
+    // line 44
     /**
      * @return iterable<null|scalar|\Stringable>
      */
     public function block__content(array $context, array $blocks = []): iterable
     {
         $macros = $this->macros;
-        // line 40
+        // line 45
         yield "                    ";
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/output.html.twig");
         yield "
@@ -193,7 +201,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  168 => 40,  161 => 39,  151 => 65,  149 => 62,  145 => 61,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  176 => 45,  169 => 44,  159 => 70,  157 => 67,  153 => 66,  149 => 64,  135 => 52,  133 => 51,  127 => 47,  125 => 44,  115 => 37,  111 => 36,  101 => 29,  94 => 25,  88 => 22,  84 => 21,  80 => 20,  76 => 19,  72 => 18,  68 => 17,  63 => 15,  58 => 12,  56 => 11,  55 => 10,  54 => 8,  53 => 7,  52 => 5,  49 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
